pub enum TransferLimitError<E, C = usize> {
LimitExceeded {
limit: C,
actual: C,
},
CounterOverflow {
bytes_seen: C,
chunk_len: usize,
},
Inner {
source: E,
},
}Expand description
Error returned by a transfer-limited stream.
Variants
LimitExceeded
The stream produced more bytes than allowed.
Fields

limit: CConfigured maximum number of bytes.

actual: CNumber of bytes observed after reading the chunk that crossed the limit.
CounterOverflow
The cumulative byte count cannot be represented by the selected counter.
Fields

bytes_seen: CNumber of bytes counted before reading the chunk that overflowed.
Inner
The wrapped stream returned an error.
Fields

source: EOriginal stream error.
Implementations
Sourceimpl<E, C> TransferLimitError<E, C>
impl<E, C> TransferLimitError<E, C>
Sourcepub fn is_limit_exceeded(&self) -> bool
pub fn is_limit_exceeded(&self) -> bool
Returns true when this error represents an exceeded transfer limit.
Sourcepub fn is_counter_overflow(&self) -> bool
pub fn is_counter_overflow(&self) -> bool
Returns true when the selected counter type could not represent the
cumulative byte count.
Sourcepub fn into_inner(self) -> Option<E>
pub fn into_inner(self) -> Option<E>
Returns the wrapped stream error, if this is an inner stream error.