TransferLimitError

Enum TransferLimitError 

pub enum TransferLimitError<E, C = usize> {
    LimitExceeded {
        limit: C,
        actual: C,
    },
    CounterOverflow {
        bytes_seen: C,
        chunk_len: usize,
    },
    Inner {
        source: E,
    },
}
Error returned by a transfer-limited stream.

Variants



LimitExceeded

The stream produced more bytes than allowed.

Fields

limit: C

Configured maximum number of bytes.

actual: C

Number of bytes observed after reading the chunk that crossed the limit.



CounterOverflow

The cumulative byte count cannot be represented by the selected counter.

Fields

bytes_seen: C

Number of bytes counted before reading the chunk that overflowed.

chunk_len: usize

Byte length of the chunk that could not be added to the counter.



Inner

The wrapped stream returned an error.

Fields

source: E

Original stream error.

Implementations

Source

impl<E, C> TransferLimitError<E, C>

pub fn is_limit_exceeded(&self) -> bool

Returns true when this error represents an exceeded transfer limit.

pub fn is_counter_overflow(&self) -> bool

Returns true when the selected counter type could not represent the cumulative byte count.

pub fn into_inner(self) -> Option<E>

Returns the wrapped stream error, if this is an inner stream error.