pub struct TransferLimit<C = usize, P = NoopProgress<C>> { /* private fields */ }Expand description
Builder for applying byte-count transfer limits to fallible streams.
Implementations
Sourceimpl TransferLimit<usize, NoopProgress<usize>>
impl TransferLimit<usize, NoopProgress<usize>>
Sourceimpl<C> TransferLimit<C, NoopProgress<C>>where
C: TransferCounter,
impl<C> TransferLimit<C, NoopProgress<C>>where
C: TransferCounter,
Sourcepub fn from_limit(limit: C) -> Self
pub fn from_limit(limit: C) -> Self
Create a transfer limit using an explicit counter type.
Sourcepub fn from_optional_limit(limit: Option<C>) -> Self
pub fn from_optional_limit(limit: Option<C>) -> Self
Create a transfer limit from an optional byte limit using an explicit counter type.
Sourceimpl<C, P> TransferLimit<C, P>where
C: TransferCounter,
impl<C, P> TransferLimit<C, P>where
C: TransferCounter,
Sourcepub fn with_limit(self, limit: C) -> Self
pub fn with_limit(self, limit: C) -> Self
Set the maximum allowed number of bytes.
A stream is allowed to produce exactly limit bytes. It fails on the
first chunk that makes the cumulative total greater than limit.
Sourcepub fn without_limit(self) -> Self
pub fn without_limit(self) -> Self
Remove the maximum byte limit while keeping progress tracking.
Sourcepub fn on_progress<F>(self, on_progress: F) -> TransferLimit<C, F>where
F: FnMut(C),
pub fn on_progress<F>(self, on_progress: F) -> TransferLimit<C, F>where
F: FnMut(C),
Replace the progress callback.
The callback receives cumulative bytes after every successful chunk read from the inner stream, including the chunk that crosses the limit.